Documentation
¶
Overview ¶
Code generated by protoc-gen-go-pulsar. DO NOT EDIT.
Index ¶
- Variables
- type Asset
- func (*Asset) Descriptor() ([]byte, []int)deprecated
- func (x *Asset) GetChain() string
- func (x *Asset) GetSecured() bool
- func (x *Asset) GetSymbol() string
- func (x *Asset) GetSynth() bool
- func (x *Asset) GetTicker() string
- func (x *Asset) GetTrade() bool
- func (*Asset) ProtoMessage()
- func (x *Asset) ProtoReflect() protoreflect.Message
- func (x *Asset) Reset()
- func (x *Asset) String() string
- type AttestErrataTx
- func (*AttestErrataTx) Descriptor() ([]byte, []int)deprecated
- func (x *AttestErrataTx) GetAttestation() *Attestation
- func (x *AttestErrataTx) GetErrataTx() *ErrataTx
- func (*AttestErrataTx) ProtoMessage()
- func (x *AttestErrataTx) ProtoReflect() protoreflect.Message
- func (x *AttestErrataTx) Reset()
- func (x *AttestErrataTx) String() string
- type AttestNetworkFee
- func (*AttestNetworkFee) Descriptor() ([]byte, []int)deprecated
- func (x *AttestNetworkFee) GetAttestation() *Attestation
- func (x *AttestNetworkFee) GetNetworkFee() *NetworkFee
- func (*AttestNetworkFee) ProtoMessage()
- func (x *AttestNetworkFee) ProtoReflect() protoreflect.Message
- func (x *AttestNetworkFee) Reset()
- func (x *AttestNetworkFee) String() string
- type AttestSolvency
- func (*AttestSolvency) Descriptor() ([]byte, []int)deprecated
- func (x *AttestSolvency) GetAttestation() *Attestation
- func (x *AttestSolvency) GetSolvency() *Solvency
- func (*AttestSolvency) ProtoMessage()
- func (x *AttestSolvency) ProtoReflect() protoreflect.Message
- func (x *AttestSolvency) Reset()
- func (x *AttestSolvency) String() string
- type AttestTx
- func (*AttestTx) Descriptor() ([]byte, []int)deprecated
- func (x *AttestTx) GetAllowFutureObservation() bool
- func (x *AttestTx) GetAttestation() *Attestation
- func (x *AttestTx) GetInbound() bool
- func (x *AttestTx) GetObsTx() *ObservedTx
- func (*AttestTx) ProtoMessage()
- func (x *AttestTx) ProtoReflect() protoreflect.Message
- func (x *AttestTx) Reset()
- func (x *AttestTx) String() string
- type Attestation
- func (*Attestation) Descriptor() ([]byte, []int)deprecated
- func (x *Attestation) GetPubKey() []byte
- func (x *Attestation) GetSignature() []byte
- func (*Attestation) ProtoMessage()
- func (x *Attestation) ProtoReflect() protoreflect.Message
- func (x *Attestation) Reset()
- func (x *Attestation) String() string
- type Coin
- type ErrataTx
- type Fee
- type NetworkFee
- func (*NetworkFee) Descriptor() ([]byte, []int)deprecated
- func (x *NetworkFee) GetChain() string
- func (x *NetworkFee) GetHeight() int64
- func (x *NetworkFee) GetTransactionRate() uint64
- func (x *NetworkFee) GetTransactionSize() uint64
- func (*NetworkFee) ProtoMessage()
- func (x *NetworkFee) ProtoReflect() protoreflect.Message
- func (x *NetworkFee) Reset()
- func (x *NetworkFee) String() string
- type ObservedTx
- func (*ObservedTx) Descriptor() ([]byte, []int)deprecated
- func (x *ObservedTx) GetAggregator() string
- func (x *ObservedTx) GetAggregatorTarget() string
- func (x *ObservedTx) GetAggregatorTargetLimit() string
- func (x *ObservedTx) GetBlockHeight() int64
- func (x *ObservedTx) GetFinaliseHeight() int64
- func (x *ObservedTx) GetKeysignMs() int64
- func (x *ObservedTx) GetObservedPubKey() string
- func (x *ObservedTx) GetOutHashes() []string
- func (x *ObservedTx) GetSigners() []string
- func (x *ObservedTx) GetStatus() Status
- func (x *ObservedTx) GetTx() *Tx
- func (*ObservedTx) ProtoMessage()
- func (x *ObservedTx) ProtoReflect() protoreflect.Message
- func (x *ObservedTx) Reset()
- func (x *ObservedTx) String() string
- type ProtoUint
- type PubKeySet
- type QuorumErrataTx
- func (*QuorumErrataTx) Descriptor() ([]byte, []int)deprecated
- func (x *QuorumErrataTx) GetAttestations() []*Attestation
- func (x *QuorumErrataTx) GetErrataTx() *ErrataTx
- func (*QuorumErrataTx) ProtoMessage()
- func (x *QuorumErrataTx) ProtoReflect() protoreflect.Message
- func (x *QuorumErrataTx) Reset()
- func (x *QuorumErrataTx) String() string
- type QuorumNetworkFee
- func (*QuorumNetworkFee) Descriptor() ([]byte, []int)deprecated
- func (x *QuorumNetworkFee) GetAttestations() []*Attestation
- func (x *QuorumNetworkFee) GetNetworkFee() *NetworkFee
- func (*QuorumNetworkFee) ProtoMessage()
- func (x *QuorumNetworkFee) ProtoReflect() protoreflect.Message
- func (x *QuorumNetworkFee) Reset()
- func (x *QuorumNetworkFee) String() string
- type QuorumSolvency
- func (*QuorumSolvency) Descriptor() ([]byte, []int)deprecated
- func (x *QuorumSolvency) GetAttestations() []*Attestation
- func (x *QuorumSolvency) GetSolvency() *Solvency
- func (*QuorumSolvency) ProtoMessage()
- func (x *QuorumSolvency) ProtoReflect() protoreflect.Message
- func (x *QuorumSolvency) Reset()
- func (x *QuorumSolvency) String() string
- type QuorumState
- func (*QuorumState) Descriptor() ([]byte, []int)deprecated
- func (x *QuorumState) GetQuoErrataTxs() []*QuorumErrataTx
- func (x *QuorumState) GetQuoNetworkFees() []*QuorumNetworkFee
- func (x *QuorumState) GetQuoSolvencies() []*QuorumSolvency
- func (x *QuorumState) GetQuoTxs() []*QuorumTx
- func (*QuorumState) ProtoMessage()
- func (x *QuorumState) ProtoReflect() protoreflect.Message
- func (x *QuorumState) Reset()
- func (x *QuorumState) String() string
- type QuorumTx
- func (*QuorumTx) Descriptor() ([]byte, []int)deprecated
- func (x *QuorumTx) GetAllowFutureObservation() bool
- func (x *QuorumTx) GetAttestations() []*Attestation
- func (x *QuorumTx) GetInbound() bool
- func (x *QuorumTx) GetObsTx() *ObservedTx
- func (*QuorumTx) ProtoMessage()
- func (x *QuorumTx) ProtoReflect() protoreflect.Message
- func (x *QuorumTx) Reset()
- func (x *QuorumTx) String() string
- type Solvency
- func (*Solvency) Descriptor() ([]byte, []int)deprecated
- func (x *Solvency) GetChain() string
- func (x *Solvency) GetCoins() []*Coin
- func (x *Solvency) GetHeight() int64
- func (x *Solvency) GetId() string
- func (x *Solvency) GetPubKey() string
- func (*Solvency) ProtoMessage()
- func (x *Solvency) ProtoReflect() protoreflect.Message
- func (x *Solvency) Reset()
- func (x *Solvency) String() string
- type Status
- type Tx
- func (*Tx) Descriptor() ([]byte, []int)deprecated
- func (x *Tx) GetChain() string
- func (x *Tx) GetCoins() []*Coin
- func (x *Tx) GetFromAddress() string
- func (x *Tx) GetGas() []*Coin
- func (x *Tx) GetId() string
- func (x *Tx) GetMemo() string
- func (x *Tx) GetToAddress() string
- func (*Tx) ProtoMessage()
- func (x *Tx) ProtoReflect() protoreflect.Message
- func (x *Tx) Reset()
- func (x *Tx) String() string
Constants ¶
This section is empty.
Variables ¶
var ( Status_name = map[int32]string{ 0: "incomplete", 1: "done", 2: "reverted", } Status_value = map[string]int32{ "incomplete": 0, "done": 1, "reverted": 2, } )
Enum value maps for Status.
var File_common_common_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Asset ¶
type Asset struct {
Chain string `protobuf:"bytes,1,opt,name=chain,proto3" json:"chain,omitempty"`
Symbol string `protobuf:"bytes,2,opt,name=symbol,proto3" json:"symbol,omitempty"`
Ticker string `protobuf:"bytes,3,opt,name=ticker,proto3" json:"ticker,omitempty"`
Synth bool `protobuf:"varint,4,opt,name=synth,proto3" json:"synth,omitempty"`
Trade bool `protobuf:"varint,5,opt,name=trade,proto3" json:"trade,omitempty"`
Secured bool `protobuf:"varint,6,opt,name=secured,proto3" json:"secured,omitempty"`
// contains filtered or unexported fields
}
func (*Asset) Descriptor
deprecated
func (*Asset) GetSecured ¶
func (*Asset) ProtoMessage ¶
func (*Asset) ProtoMessage()
func (*Asset) ProtoReflect ¶
func (x *Asset) ProtoReflect() protoreflect.Message
type AttestErrataTx ¶
type AttestErrataTx struct {
ErrataTx *ErrataTx `protobuf:"bytes,1,opt,name=errata_tx,json=errataTx,proto3" json:"errata_tx,omitempty"`
Attestation *Attestation `protobuf:"bytes,2,opt,name=attestation,proto3" json:"attestation,omitempty"`
// contains filtered or unexported fields
}
func (*AttestErrataTx) Descriptor
deprecated
func (*AttestErrataTx) Descriptor() ([]byte, []int)
Deprecated: Use AttestErrataTx.ProtoReflect.Descriptor instead.
func (*AttestErrataTx) GetAttestation ¶
func (x *AttestErrataTx) GetAttestation() *Attestation
func (*AttestErrataTx) GetErrataTx ¶
func (x *AttestErrataTx) GetErrataTx() *ErrataTx
func (*AttestErrataTx) ProtoMessage ¶
func (*AttestErrataTx) ProtoMessage()
func (*AttestErrataTx) ProtoReflect ¶
func (x *AttestErrataTx) ProtoReflect() protoreflect.Message
func (*AttestErrataTx) Reset ¶
func (x *AttestErrataTx) Reset()
func (*AttestErrataTx) String ¶
func (x *AttestErrataTx) String() string
type AttestNetworkFee ¶
type AttestNetworkFee struct {
NetworkFee *NetworkFee `protobuf:"bytes,1,opt,name=network_fee,json=networkFee,proto3" json:"network_fee,omitempty"`
Attestation *Attestation `protobuf:"bytes,2,opt,name=attestation,proto3" json:"attestation,omitempty"`
// contains filtered or unexported fields
}
func (*AttestNetworkFee) Descriptor
deprecated
func (*AttestNetworkFee) Descriptor() ([]byte, []int)
Deprecated: Use AttestNetworkFee.ProtoReflect.Descriptor instead.
func (*AttestNetworkFee) GetAttestation ¶
func (x *AttestNetworkFee) GetAttestation() *Attestation
func (*AttestNetworkFee) GetNetworkFee ¶
func (x *AttestNetworkFee) GetNetworkFee() *NetworkFee
func (*AttestNetworkFee) ProtoMessage ¶
func (*AttestNetworkFee) ProtoMessage()
func (*AttestNetworkFee) ProtoReflect ¶
func (x *AttestNetworkFee) ProtoReflect() protoreflect.Message
func (*AttestNetworkFee) Reset ¶
func (x *AttestNetworkFee) Reset()
func (*AttestNetworkFee) String ¶
func (x *AttestNetworkFee) String() string
type AttestSolvency ¶
type AttestSolvency struct {
Solvency *Solvency `protobuf:"bytes,1,opt,name=solvency,proto3" json:"solvency,omitempty"`
Attestation *Attestation `protobuf:"bytes,2,opt,name=attestation,proto3" json:"attestation,omitempty"`
// contains filtered or unexported fields
}
func (*AttestSolvency) Descriptor
deprecated
func (*AttestSolvency) Descriptor() ([]byte, []int)
Deprecated: Use AttestSolvency.ProtoReflect.Descriptor instead.
func (*AttestSolvency) GetAttestation ¶
func (x *AttestSolvency) GetAttestation() *Attestation
func (*AttestSolvency) GetSolvency ¶
func (x *AttestSolvency) GetSolvency() *Solvency
func (*AttestSolvency) ProtoMessage ¶
func (*AttestSolvency) ProtoMessage()
func (*AttestSolvency) ProtoReflect ¶
func (x *AttestSolvency) ProtoReflect() protoreflect.Message
func (*AttestSolvency) Reset ¶
func (x *AttestSolvency) Reset()
func (*AttestSolvency) String ¶
func (x *AttestSolvency) String() string
type AttestTx ¶
type AttestTx struct {
ObsTx *ObservedTx `protobuf:"bytes,1,opt,name=obsTx,proto3" json:"obsTx,omitempty"`
Attestation *Attestation `protobuf:"bytes,2,opt,name=attestation,proto3" json:"attestation,omitempty"`
Inbound bool `protobuf:"varint,3,opt,name=inbound,proto3" json:"inbound,omitempty"`
AllowFutureObservation bool `` // allow future observation if this is an instant observation and gas is wrong, requiring future observation to correct
/* 130-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*AttestTx) Descriptor
deprecated
func (*AttestTx) GetAllowFutureObservation ¶
func (*AttestTx) GetAttestation ¶
func (x *AttestTx) GetAttestation() *Attestation
func (*AttestTx) GetInbound ¶
func (*AttestTx) GetObsTx ¶
func (x *AttestTx) GetObsTx() *ObservedTx
func (*AttestTx) ProtoMessage ¶
func (*AttestTx) ProtoMessage()
func (*AttestTx) ProtoReflect ¶
func (x *AttestTx) ProtoReflect() protoreflect.Message
type Attestation ¶
type Attestation struct {
PubKey []byte `protobuf:"bytes,1,opt,name=PubKey,proto3" json:"PubKey,omitempty"`
Signature []byte `protobuf:"bytes,2,opt,name=Signature,proto3" json:"Signature,omitempty"`
// contains filtered or unexported fields
}
func (*Attestation) Descriptor
deprecated
func (*Attestation) Descriptor() ([]byte, []int)
Deprecated: Use Attestation.ProtoReflect.Descriptor instead.
func (*Attestation) GetPubKey ¶
func (x *Attestation) GetPubKey() []byte
func (*Attestation) GetSignature ¶
func (x *Attestation) GetSignature() []byte
func (*Attestation) ProtoMessage ¶
func (*Attestation) ProtoMessage()
func (*Attestation) ProtoReflect ¶
func (x *Attestation) ProtoReflect() protoreflect.Message
func (*Attestation) Reset ¶
func (x *Attestation) Reset()
func (*Attestation) String ¶
func (x *Attestation) String() string
type Coin ¶
type Coin struct {
Asset *Asset `protobuf:"bytes,1,opt,name=asset,proto3" json:"asset,omitempty"`
Amount string `protobuf:"bytes,2,opt,name=amount,proto3" json:"amount,omitempty"`
Decimals int64 `protobuf:"varint,3,opt,name=decimals,proto3" json:"decimals,omitempty"`
// contains filtered or unexported fields
}
func (*Coin) Descriptor
deprecated
func (*Coin) GetDecimals ¶
func (*Coin) ProtoMessage ¶
func (*Coin) ProtoMessage()
func (*Coin) ProtoReflect ¶
func (x *Coin) ProtoReflect() protoreflect.Message
type ErrataTx ¶
type ErrataTx struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Chain string `protobuf:"bytes,2,opt,name=chain,proto3" json:"chain,omitempty"`
// contains filtered or unexported fields
}
func (*ErrataTx) Descriptor
deprecated
func (*ErrataTx) ProtoMessage ¶
func (*ErrataTx) ProtoMessage()
func (*ErrataTx) ProtoReflect ¶
func (x *ErrataTx) ProtoReflect() protoreflect.Message
type Fee ¶
type Fee struct {
Coins []*Coin `protobuf:"bytes,1,rep,name=coins,proto3" json:"coins,omitempty"`
PoolDeduct string `protobuf:"bytes,2,opt,name=pool_deduct,json=poolDeduct,proto3" json:"pool_deduct,omitempty"`
// contains filtered or unexported fields
}
func (*Fee) Descriptor
deprecated
func (*Fee) GetPoolDeduct ¶
func (*Fee) ProtoMessage ¶
func (*Fee) ProtoMessage()
func (*Fee) ProtoReflect ¶
func (x *Fee) ProtoReflect() protoreflect.Message
type NetworkFee ¶
type NetworkFee struct {
Height int64 `protobuf:"varint,1,opt,name=height,proto3" json:"height,omitempty"`
Chain string `protobuf:"bytes,2,opt,name=chain,proto3" json:"chain,omitempty"`
TransactionSize uint64 `protobuf:"varint,3,opt,name=transaction_size,json=transactionSize,proto3" json:"transaction_size,omitempty"`
TransactionRate uint64 `protobuf:"varint,4,opt,name=transaction_rate,json=transactionRate,proto3" json:"transaction_rate,omitempty"`
// contains filtered or unexported fields
}
func (*NetworkFee) Descriptor
deprecated
func (*NetworkFee) Descriptor() ([]byte, []int)
Deprecated: Use NetworkFee.ProtoReflect.Descriptor instead.
func (*NetworkFee) GetChain ¶
func (x *NetworkFee) GetChain() string
func (*NetworkFee) GetHeight ¶
func (x *NetworkFee) GetHeight() int64
func (*NetworkFee) GetTransactionRate ¶
func (x *NetworkFee) GetTransactionRate() uint64
func (*NetworkFee) GetTransactionSize ¶
func (x *NetworkFee) GetTransactionSize() uint64
func (*NetworkFee) ProtoMessage ¶
func (*NetworkFee) ProtoMessage()
func (*NetworkFee) ProtoReflect ¶
func (x *NetworkFee) ProtoReflect() protoreflect.Message
func (*NetworkFee) Reset ¶
func (x *NetworkFee) Reset()
func (*NetworkFee) String ¶
func (x *NetworkFee) String() string
type ObservedTx ¶
type ObservedTx struct {
Tx *Tx `protobuf:"bytes,1,opt,name=tx,proto3" json:"tx,omitempty"`
Status Status `protobuf:"varint,2,opt,name=status,proto3,enum=common.Status" json:"status,omitempty"`
OutHashes []string `protobuf:"bytes,3,rep,name=out_hashes,json=outHashes,proto3" json:"out_hashes,omitempty"`
BlockHeight int64 `protobuf:"varint,4,opt,name=block_height,json=blockHeight,proto3" json:"block_height,omitempty"`
Signers []string `protobuf:"bytes,5,rep,name=signers,proto3" json:"signers,omitempty"`
ObservedPubKey string `protobuf:"bytes,6,opt,name=observed_pub_key,json=observedPubKey,proto3" json:"observed_pub_key,omitempty"`
KeysignMs int64 `protobuf:"varint,7,opt,name=keysign_ms,json=keysignMs,proto3" json:"keysign_ms,omitempty"`
FinaliseHeight int64 `protobuf:"varint,8,opt,name=finalise_height,json=finaliseHeight,proto3" json:"finalise_height,omitempty"`
Aggregator string `protobuf:"bytes,9,opt,name=aggregator,proto3" json:"aggregator,omitempty"`
AggregatorTarget string `protobuf:"bytes,10,opt,name=aggregator_target,json=aggregatorTarget,proto3" json:"aggregator_target,omitempty"`
AggregatorTargetLimit string `` /* 127-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*ObservedTx) Descriptor
deprecated
func (*ObservedTx) Descriptor() ([]byte, []int)
Deprecated: Use ObservedTx.ProtoReflect.Descriptor instead.
func (*ObservedTx) GetAggregator ¶
func (x *ObservedTx) GetAggregator() string
func (*ObservedTx) GetAggregatorTarget ¶
func (x *ObservedTx) GetAggregatorTarget() string
func (*ObservedTx) GetAggregatorTargetLimit ¶
func (x *ObservedTx) GetAggregatorTargetLimit() string
func (*ObservedTx) GetBlockHeight ¶
func (x *ObservedTx) GetBlockHeight() int64
func (*ObservedTx) GetFinaliseHeight ¶
func (x *ObservedTx) GetFinaliseHeight() int64
func (*ObservedTx) GetKeysignMs ¶
func (x *ObservedTx) GetKeysignMs() int64
func (*ObservedTx) GetObservedPubKey ¶
func (x *ObservedTx) GetObservedPubKey() string
func (*ObservedTx) GetOutHashes ¶
func (x *ObservedTx) GetOutHashes() []string
func (*ObservedTx) GetSigners ¶
func (x *ObservedTx) GetSigners() []string
func (*ObservedTx) GetStatus ¶
func (x *ObservedTx) GetStatus() Status
func (*ObservedTx) GetTx ¶
func (x *ObservedTx) GetTx() *Tx
func (*ObservedTx) ProtoMessage ¶
func (*ObservedTx) ProtoMessage()
func (*ObservedTx) ProtoReflect ¶
func (x *ObservedTx) ProtoReflect() protoreflect.Message
func (*ObservedTx) Reset ¶
func (x *ObservedTx) Reset()
func (*ObservedTx) String ¶
func (x *ObservedTx) String() string
type ProtoUint ¶
type ProtoUint struct {
Value string `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
// contains filtered or unexported fields
}
func (*ProtoUint) Descriptor
deprecated
func (*ProtoUint) ProtoMessage ¶
func (*ProtoUint) ProtoMessage()
func (*ProtoUint) ProtoReflect ¶
func (x *ProtoUint) ProtoReflect() protoreflect.Message
type PubKeySet ¶
type PubKeySet struct {
Secp256K1 string `protobuf:"bytes,1,opt,name=secp256k1,proto3" json:"secp256k1,omitempty"`
Ed25519 string `protobuf:"bytes,2,opt,name=ed25519,proto3" json:"ed25519,omitempty"`
// contains filtered or unexported fields
}
PubKeySet contains two pub keys , secp256k1 and ed25519
func (*PubKeySet) Descriptor
deprecated
func (*PubKeySet) GetEd25519 ¶
func (*PubKeySet) GetSecp256K1 ¶
func (*PubKeySet) ProtoMessage ¶
func (*PubKeySet) ProtoMessage()
func (*PubKeySet) ProtoReflect ¶
func (x *PubKeySet) ProtoReflect() protoreflect.Message
type QuorumErrataTx ¶
type QuorumErrataTx struct {
ErrataTx *ErrataTx `protobuf:"bytes,1,opt,name=errata_tx,json=errataTx,proto3" json:"errata_tx,omitempty"`
Attestations []*Attestation `protobuf:"bytes,2,rep,name=attestations,proto3" json:"attestations,omitempty"`
// contains filtered or unexported fields
}
func (*QuorumErrataTx) Descriptor
deprecated
func (*QuorumErrataTx) Descriptor() ([]byte, []int)
Deprecated: Use QuorumErrataTx.ProtoReflect.Descriptor instead.
func (*QuorumErrataTx) GetAttestations ¶
func (x *QuorumErrataTx) GetAttestations() []*Attestation
func (*QuorumErrataTx) GetErrataTx ¶
func (x *QuorumErrataTx) GetErrataTx() *ErrataTx
func (*QuorumErrataTx) ProtoMessage ¶
func (*QuorumErrataTx) ProtoMessage()
func (*QuorumErrataTx) ProtoReflect ¶
func (x *QuorumErrataTx) ProtoReflect() protoreflect.Message
func (*QuorumErrataTx) Reset ¶
func (x *QuorumErrataTx) Reset()
func (*QuorumErrataTx) String ¶
func (x *QuorumErrataTx) String() string
type QuorumNetworkFee ¶
type QuorumNetworkFee struct {
NetworkFee *NetworkFee `protobuf:"bytes,1,opt,name=network_fee,json=networkFee,proto3" json:"network_fee,omitempty"`
Attestations []*Attestation `protobuf:"bytes,2,rep,name=attestations,proto3" json:"attestations,omitempty"`
// contains filtered or unexported fields
}
func (*QuorumNetworkFee) Descriptor
deprecated
func (*QuorumNetworkFee) Descriptor() ([]byte, []int)
Deprecated: Use QuorumNetworkFee.ProtoReflect.Descriptor instead.
func (*QuorumNetworkFee) GetAttestations ¶
func (x *QuorumNetworkFee) GetAttestations() []*Attestation
func (*QuorumNetworkFee) GetNetworkFee ¶
func (x *QuorumNetworkFee) GetNetworkFee() *NetworkFee
func (*QuorumNetworkFee) ProtoMessage ¶
func (*QuorumNetworkFee) ProtoMessage()
func (*QuorumNetworkFee) ProtoReflect ¶
func (x *QuorumNetworkFee) ProtoReflect() protoreflect.Message
func (*QuorumNetworkFee) Reset ¶
func (x *QuorumNetworkFee) Reset()
func (*QuorumNetworkFee) String ¶
func (x *QuorumNetworkFee) String() string
type QuorumSolvency ¶
type QuorumSolvency struct {
Solvency *Solvency `protobuf:"bytes,1,opt,name=solvency,proto3" json:"solvency,omitempty"`
Attestations []*Attestation `protobuf:"bytes,2,rep,name=attestations,proto3" json:"attestations,omitempty"`
// contains filtered or unexported fields
}
func (*QuorumSolvency) Descriptor
deprecated
func (*QuorumSolvency) Descriptor() ([]byte, []int)
Deprecated: Use QuorumSolvency.ProtoReflect.Descriptor instead.
func (*QuorumSolvency) GetAttestations ¶
func (x *QuorumSolvency) GetAttestations() []*Attestation
func (*QuorumSolvency) GetSolvency ¶
func (x *QuorumSolvency) GetSolvency() *Solvency
func (*QuorumSolvency) ProtoMessage ¶
func (*QuorumSolvency) ProtoMessage()
func (*QuorumSolvency) ProtoReflect ¶
func (x *QuorumSolvency) ProtoReflect() protoreflect.Message
func (*QuorumSolvency) Reset ¶
func (x *QuorumSolvency) Reset()
func (*QuorumSolvency) String ¶
func (x *QuorumSolvency) String() string
type QuorumState ¶
type QuorumState struct {
QuoTxs []*QuorumTx `protobuf:"bytes,1,rep,name=quoTxs,proto3" json:"quoTxs,omitempty"`
QuoNetworkFees []*QuorumNetworkFee `protobuf:"bytes,2,rep,name=quoNetworkFees,proto3" json:"quoNetworkFees,omitempty"`
QuoSolvencies []*QuorumSolvency `protobuf:"bytes,3,rep,name=quoSolvencies,proto3" json:"quoSolvencies,omitempty"`
QuoErrataTxs []*QuorumErrataTx `protobuf:"bytes,4,rep,name=quoErrataTxs,proto3" json:"quoErrataTxs,omitempty"`
// contains filtered or unexported fields
}
func (*QuorumState) Descriptor
deprecated
func (*QuorumState) Descriptor() ([]byte, []int)
Deprecated: Use QuorumState.ProtoReflect.Descriptor instead.
func (*QuorumState) GetQuoErrataTxs ¶
func (x *QuorumState) GetQuoErrataTxs() []*QuorumErrataTx
func (*QuorumState) GetQuoNetworkFees ¶
func (x *QuorumState) GetQuoNetworkFees() []*QuorumNetworkFee
func (*QuorumState) GetQuoSolvencies ¶
func (x *QuorumState) GetQuoSolvencies() []*QuorumSolvency
func (*QuorumState) GetQuoTxs ¶
func (x *QuorumState) GetQuoTxs() []*QuorumTx
func (*QuorumState) ProtoMessage ¶
func (*QuorumState) ProtoMessage()
func (*QuorumState) ProtoReflect ¶
func (x *QuorumState) ProtoReflect() protoreflect.Message
func (*QuorumState) Reset ¶
func (x *QuorumState) Reset()
func (*QuorumState) String ¶
func (x *QuorumState) String() string
type QuorumTx ¶
type QuorumTx struct {
ObsTx *ObservedTx `protobuf:"bytes,1,opt,name=obsTx,proto3" json:"obsTx,omitempty"`
Attestations []*Attestation `protobuf:"bytes,2,rep,name=attestations,proto3" json:"attestations,omitempty"`
Inbound bool `protobuf:"varint,3,opt,name=inbound,proto3" json:"inbound,omitempty"`
AllowFutureObservation bool `` // allow future observation if this is an instant observation and gas is wrong, requiring future observation to correct
/* 130-byte string literal not displayed */
// contains filtered or unexported fields
}
func (*QuorumTx) Descriptor
deprecated
func (*QuorumTx) GetAllowFutureObservation ¶
func (*QuorumTx) GetAttestations ¶
func (x *QuorumTx) GetAttestations() []*Attestation
func (*QuorumTx) GetInbound ¶
func (*QuorumTx) GetObsTx ¶
func (x *QuorumTx) GetObsTx() *ObservedTx
func (*QuorumTx) ProtoMessage ¶
func (*QuorumTx) ProtoMessage()
func (*QuorumTx) ProtoReflect ¶
func (x *QuorumTx) ProtoReflect() protoreflect.Message
type Solvency ¶
type Solvency struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Chain string `protobuf:"bytes,2,opt,name=chain,proto3" json:"chain,omitempty"`
PubKey string `protobuf:"bytes,3,opt,name=pub_key,json=pubKey,proto3" json:"pub_key,omitempty"`
Coins []*Coin `protobuf:"bytes,4,rep,name=coins,proto3" json:"coins,omitempty"`
Height int64 `protobuf:"varint,5,opt,name=height,proto3" json:"height,omitempty"`
// contains filtered or unexported fields
}
func (*Solvency) Descriptor
deprecated
func (*Solvency) ProtoMessage ¶
func (*Solvency) ProtoMessage()
func (*Solvency) ProtoReflect ¶
func (x *Solvency) ProtoReflect() protoreflect.Message
type Status ¶
type Status int32
func (Status) Descriptor ¶
func (Status) Descriptor() protoreflect.EnumDescriptor
func (Status) EnumDescriptor
deprecated
func (Status) Number ¶
func (x Status) Number() protoreflect.EnumNumber
func (Status) Type ¶
func (Status) Type() protoreflect.EnumType
type Tx ¶
type Tx struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Chain string `protobuf:"bytes,2,opt,name=chain,proto3" json:"chain,omitempty"`
FromAddress string `protobuf:"bytes,3,opt,name=from_address,json=fromAddress,proto3" json:"from_address,omitempty"`
ToAddress string `protobuf:"bytes,4,opt,name=to_address,json=toAddress,proto3" json:"to_address,omitempty"`
Coins []*Coin `protobuf:"bytes,5,rep,name=coins,proto3" json:"coins,omitempty"`
Gas []*Coin `protobuf:"bytes,6,rep,name=gas,proto3" json:"gas,omitempty"`
Memo string `protobuf:"bytes,7,opt,name=memo,proto3" json:"memo,omitempty"`
// contains filtered or unexported fields
}
func (*Tx) Descriptor
deprecated
func (*Tx) GetFromAddress ¶
func (*Tx) GetToAddress ¶
func (*Tx) ProtoMessage ¶
func (*Tx) ProtoMessage()
func (*Tx) ProtoReflect ¶
func (x *Tx) ProtoReflect() protoreflect.Message